Crate pounce_common

Crate pounce_common 

POUNCE common primitives.

Port of Ipopt’s src/Common/: scalar types, exceptions, journalist, tagged-object change tracking, cached results, registered options and options list, utility helpers, and timed-task accumulators.

Re-exports

pub use cached::Cache;
pub use diagnostics::DiagCategory;
pub use diagnostics::DiagnosticsConfig;
pub use diagnostics::DiagnosticsState;
pub use diagnostics::DumpFormat;
pub use diagnostics::IterSpec;
pub use exception::ExceptionKind;
pub use exception::SolverException;
pub use journalist::FileJournal;
pub use journalist::Journal;
pub use journalist::JournalCategory;
pub use journalist::JournalLevel;
pub use journalist::Journalist;
pub use journalist::StringJournal;
pub use options_list::OptionsList;
pub use reg_options::DefaultValue;
pub use reg_options::OptionType;
pub use reg_options::RegisteredOption;
pub use reg_options::RegisteredOptions;
pub use reg_options::StringEntry;
pub use tagged::Tag;
pub use tagged::TaggedCell;
pub use tagged::TaggedObject;
pub use timing::TimedTask;
pub use timing::TimingStatistics;
pub use types::Index;
pub use types::Number;
pub use types::NLP_LOWER_BOUND_INF;
pub use types::NLP_UPPER_BOUND_INF;

Modules

cached
Tag-keyed result cache.
diagnostics
Diagnostic-dump infrastructure shared by the solver and the CLI.
exception
POUNCE exceptions.
journalist
Logging / journaling.
options_list
User-set options list.
reg_options
Registered options registry.
style
Tiger / rust / warm branded color palette for POUNCE output (pounce#71).
tagged
Tagged-object change tracking.
timing
Per-task timing accumulator.
types
Fundamental scalar types.
utils
Numerical and timing utilities.

Macros

assert_exc
Macro replacement for ASSERT_EXCEPTION(cond, kind, msg).
throw
Macro replacement for Ipopt’s THROW_EXCEPTION(kind, msg). Produces a Result::Err(SolverException) using file!()/line!().