Journalist

Struct Journalist 

pub struct Journalist { /* private fields */ }
The Journalist owns a list of journals and dispatches messages. Mirrors Ipopt::Journalist.

Implementations

Source

impl Journalist

pub fn new() -> Self

pub fn add_journal(&self, j: Arc<dyn Journal>) -> bool

pub fn add_file_journal( &self, location_name: &str, fname: &str, default_level: JournalLevel, append: bool, ) -> Option<Arc<FileJournal>>

Convenience: add a FileJournal writing to fname.

pub fn get_journal(&self, location_name: &str) -> Option<Arc<dyn Journal>>

pub fn delete_all_journals(&self)

pub fn print(&self, level: JournalLevel, category: JournalCategory, s: &str)

Emit a pre-formatted string to every accepting journal. Equivalent to Journalist::Printf after the C-style format expansion has been done in the caller.

pub fn print_indented( &self, level: JournalLevel, category: JournalCategory, indent_level: Index, s: &str, )

Mirrors PrintfIndented — prepends 2 * indent_level spaces.

pub fn produce_output( &self, level: JournalLevel, category: JournalCategory, ) -> bool

Mirrors ProduceOutput — true iff at least one journal accepts.

pub fn flush_buffer(&self)