upper_bound_present

Function upper_bound_present 

pub fn upper_bound_present(hi: Number) -> bool
Is this upper bound a real bound, or the absent-bound sentinel? See lower_bound_present — an upper bound is absent only at or above NLP_UPPER_BOUND_INF.